@@ -41,10 +41,14 @@ class OuterScope(ScopeContents):
         # This will begin parsing the tree for this file and all sub trees
         # See ScopeContents._parse_scope
         super().__init__(tree, None, top_level=True)
-        #Disable warnings on unused methods, functions, or variables in outer scope
+        # Disable warnings on unused methods, functions, or variables in outer scope run
+        # after __init__ so it is not re-written
         self._this_scope_disabled_messages.append('W2007')
         self._this_scope_disabled_messages.append('W2008')
         self._this_scope_disabled_messages.append('W2009')
+        if len(tree.children) == 0:
+            #must use dummy tree as the meta element "start" has no line or column
+            self._record_message("W1003", DummyTree(data='start', line=1, column=1))
 
     @property
     def filename(self):
@@ -79,8 +83,12 @@ class OuterScope(ScopeContents):
         Return the line and column number for the python index of a given
         character
         """
-        line = next(i for i, line_end in enumerate(self._line_endings) if  line_end > char_index) + 1
-        column = char_index - self._line_endings[line-2]
+        line = next((i for i, line_end in enumerate(self._line_endings) if  line_end > char_index), len(self._line_endings)) + 1
+        if line == 1:
+            line_start = 0
+        else:
+            line_start = self._line_endings[line-2]
+        column = char_index - line_start
         return line, column
 
     def _process_scad_code(self):
