@@ -241,7 +241,8 @@ def estimate_complexity(tree):
     complex_expressions = ['list', 'let_expr', 'assert_func', 'list_comp_expr', 'function_literal']
     tokens = get_all_tokens(tree, exclude_trees=complex_expressions + ['attribute'])
     complexity = len(tokens)
-    list_exclude = copy(complex_expressions).remove('list')
+    list_exclude = copy(complex_expressions)
+    list_exclude.remove('list')
     list_trees = get_all_matching_subtrees(tree,
                                            'list',
                                            include_self=True,
@@ -249,7 +250,8 @@ def estimate_complexity(tree):
                                            exclude_trees=list_exclude)
     for list_tree in list_trees:
         complexity += estimate_list_complexity(list_tree)
-    list_comp_exclude = copy(complex_expressions).remove('list_comp_expr')
+    list_comp_exclude = copy(complex_expressions)
+    list_comp_exclude.remove('list_comp_expr')
     list_comp_trees = get_all_matching_subtrees(tree,
                                                 'list_comp_expr',
                                                 include_self=True,
